@@ -39,8 +39,7 @@ KeyError: "There is no item named 'docProps/core.xml' in the archive"
 import pytest
 
 from docx2python import docx2python
-
-from .conftest import RESOURCES
+from tests.conftest import RESOURCES
 
 FILE_WITH_DOCPROPS = RESOURCES / "example.docx"
 
